
	***************************
	* File: General School Questionnaire 
	* Questionnaire type: Education sector
	* Country: Zambia
	*****************************

	clear
	set mem 700m
	set more off
	cd  C:\

	use "C:\source\4- Data\4.1. Raw Data\generalschool.dta",clear

	**************************************************
	*** Step 1: Ensure all variables are present and labeled.
	**************************************************
	log using "C:\source\extra\generalschool_codebook_ini.smcl",replace

	codebook, compact

	log close


	**************************************************
	*** Step 2: Ensure response value labels are correct.
	**************************************************
	label save using "C:\source\4- Data\4.1. Raw Data\generalschool.dta", replace


	**************************************************
	*** Step 4: Recode missing values
	***************************************************

	qui mvdecode s2aq4a, mv(10=.n)
	qui mvdecode s2aq4b, mv(10=.n)
	qui mvdecode s2aq4c, mv(10=.n)
	qui mvdecode s2cq2ab, mv(10=.n)
	qui mvdecode s2cq2ac, mv(10=.n)
	qui mvdecode s2cq2bb, mv(10=.n)
	
	qui mvdecode s2cq2aa, mv(99=.r)	
	qui mvdecode s2cq2bc, mv(10=.n)

	qui mvdecode s2cq2cb, mv(10=.n)
	qui mvdecode s2cq2cc, mv(10=.n)
	qui mvdecode s2eq3c, mv(10=.n)
	qui mvdecode s2eq4b, mv(10=.n)
	qui mvdecode s2eq4c, mv(10=.n)
	qui mvdecode s2eq5b, mv(10=.n)
	qui mvdecode s2eq5e, mv(10=.n)

	qui mvdecode s3bq7, mv(10=.n)
	qui mvdecode s3bq9, mv(10=.n)
	qui mvdecode s3bq11, mv(10=.n)
	qui mvdecode s8bq4, mv(10=.n)
	qui mvdecode s8cq1d, mv(10=.n)
	qui mvdecode s8cq2d, mv(10=.n)
	qui mvdecode s8cq3d, mv(10=.n)
	qui mvdecode s8cq4d, mv(10=.n)
	qui mvdecode s8cq5d, mv(10=.n)

	qui mvdecode s8dq1d, mv(10=.n)
	qui mvdecode s8dq2d, mv(10=.n)
	qui mvdecode s8dq3d, mv(10=.n)
	qui mvdecode s8dq4d, mv(10=.n)
	qui mvdecode s8dq5d, mv(10=.n)
	qui mvdecode s8dq6d, mv(10=.n)

	qui mvdecode s8dq1f, mv(10=.n)
	qui mvdecode s8dq2f, mv(10=.n)
	qui mvdecode s8dq3f, mv(10=.n)
	qui mvdecode s8dq4f, mv(10=.n)
	qui mvdecode s8dq5f, mv(10=.n)
	qui mvdecode s8dq6f, mv(10=.n)

	qui mvdecode s8eq1b, mv(10=.n)
	qui mvdecode s8eq2b, mv(10=.n)
	qui mvdecode s8eq3b, mv(10=.n)
	qui mvdecode s8eq4b, mv(10=.n)
	qui mvdecode s8eq5b, mv(10=.n)
	qui mvdecode s8eq6b, mv(10=.n)
	qui mvdecode s8eq7b, mv(10=.n)

	qui mvdecode s8eq1c, mv(10=.n)
	qui mvdecode s8eq2c, mv(10=.n)
	qui mvdecode s8eq3c, mv(10=.n)
	qui mvdecode s8eq4c, mv(10=.n)
	qui mvdecode s8eq5c, mv(10=.n)
	qui mvdecode s8eq6c, mv(10=.n)
	qui mvdecode s8eq7c, mv(10=.n)



	**************************************************
	*** Step 6: Identify skip patterns
	**************************************************
	* Recode missing values to Stata missing values, for tests and data inspection.
	quietly mvdecode _all,mv (-666 = .d \ -777 = .n \ -888 = .l \ -99 = .r) 

	*skip pattern 1
	ge errors3bq4=((s3bq4==0 & s3bq5<.)|(s3bq4==0 & s3bq6<.)|(s3bq4==0 & s3bq7<.))

	*skip pattern 2
	ge errors3bq6=(s3bq6==0 & s3bq7<.)

	*skip pattern 3
	ge errors3bq8=(s3bq8==0 & s3bq9<.)
	
	
	*skip pattern 4
        ge errors3bq10=(s3bq10==2 & s3bq11<.)

	
	
	**************************************************
	*** Step 8: Identify illegal responses
	**************************************************
	log using "C:\source\extra\generalschool_inspect.smcl", replace
	inspect
	log  close


	
	**************************************************
	*** Step 10: Identify outliers
	**************************************************
	log using "C:\source\extra\generalschool_outlier.smcl", replace

	grubbs    s3q2* s3q3* s3q5*  s3q6*  s5q2*  s5q1* s5q2* s5q3*, level(99.99)
	log close




	**************************************************
	*** Step 12: Reviewing errors and computing responses
	**************************************************
	*skip pattern 1
         replace s3bq6=. if (s3bq4==0 & s3bq6==1)
	 replace s3bq5=. if (s3bq4==0 & s3bq5==0)
	 ge errors3bq4cr=((s3bq4==0 & s3bq5<.)|(s3bq4==0 & s3bq6<.)|(s3bq4==0 & s3bq7<.))

        su  err*
        drop err* grubbs*

	************************************************
	*** FINAL STEP : Delivrables
	**************************************************

	log using "C:\source\extra\generalschool_codebook.smcl", replace
	codebook, compact
	log close


	*Save cleaned data
	save "C:\source\4- Data\4.3. Clean Data\4.3.1. Final Data\generalschool_final.dta" , replace
