
	***************************
	* File: Head-Teacher Matching Questionnaire 
	* Questionnaire type: Education sector
	* Country: Zambia
	*****************************

	clear
	set mem 700m
	set more off
	cd  "C:\source\4- Data\4.1. Raw Data\"

	use "headteacher_matching.dta" ,clear

	**************************************************
	*** Step 1: Ensure all variables are present and labeled.	
	**************************************************
	log using "C:\source\extra\headteacher_matching_codebook_ini.smcl",replace
	codebook, compact
	log close

	**************************************************
	*** Step 2: Ensure response value labels are correct.
	**************************************************
	label save using "C:\source\4- Data\4.1. Raw Data\headteacher_matching.dta", replace


	**************************************************
	*** Step 3: Unique identifiers: ID
	**************************************************
	*generate unique code
	
	egen headteacher_id=concat( schoolco  teacherco)
	la var headteacher_id "headteacher_id"
	destring headteacher_id, generate(headteachID)
	drop headteacher_id

	order  schoolco teacherco headteachID


	**************************************************
	*** Step 4: Recode missing values
	***************************************************
	qui mvdecode s4aq3a, mv(10=.n)


	**************************************************
	*** Step 6: Identify skip patterns
	**************************************************
	* Recode missing values to Stata missing values, for tests and data inspection.
	quietly mvdecode _all,mv (-666 = .d \ -777 = .n \ -888 = .l \ -99 = .r) 
	
	*skip pattern 1
	ge errors4aq1=((s4aq1==2 & s4aq2<.) |(s4aq1==2 & s4aq3a<.))

	
	**************************************************
	*** Step 8: Identify illegal responses
	**************************************************
	log using "C:\source\extra\headteacher_matching_inspect.smcl", replace
	inspect
	log  close

	**************************************************
	*** Step 10: Identify outliers
	**************************************************
	grubbs   s4aq2 s4aq3a, level(99.99)


	**************************************************
	*** Step 12: Reviewing errors and computing responses
	**************************************************
	*skip pattern 1
	replace s4aq2=. if s4aq1==2 & s4aq2==0
	ge errors4aq1cr=((s4aq1==2 & s4aq2<.) |(s4aq1==2 & s4aq3a<.))


	su err*
	drop err* grubbs*	

	**************************************************
	*** FINAL STEP : Delivrables
	**************************************************
	log using "C:\source\extra\headteacher_matching_codebook.smcl", replace
	codebook, compact
	log close



	*Save cleaned data
	save "C:\source\4- Data\4.3. Clean Data\4.3.1. Final Data\headteacher_matching_final.dta" , replace
