	***************************
	* File: pupil roster questionnaire 
	* Questionnaire type: education
	* Country: Zambia
	*****************************



	capture clear
	capture log close
	clear
	set mem 700m
	set more off


	use "C:\source\4- Data\4.1. Raw Data\pupilroster.dta", clear

	**************************************************
	*** Step 1: Ensure all variables are present and labeled.
	**************************************************


	log using "C:\source\extra\pupilroster_ini.smcl", replace
	codebook, compact
	log close

	la var schoolco "school code"
	la var pupil_num "pupil number"
	destring pupil_id, generate(ID)

        drop pupil_id

        order  schoolco pupil_num ID


	**************************************************
	*** Step 3: Unique identifiers: ID
	**************************************************
	*generate unique ID

	egen pupil_id=concat( schoolco  pupil_num)

	la var pupil_id "pupil id"


       
	**************************************************
	*** Step 6: Identify skip patterns
	**************************************************
	* Recode missing values to Stata missing values, for tests and data inspection.
	quietly mvdecode _all,mv(-666 = .d \ 77 = .n \ -888 = .l \ 99 = .r) 

	*skip pattern 1
        ge errorq1=(q1==1 & q2<.) 

	*skip pattern 2
	ge errorq6=(q6==1 & q7<.)

	*skip pattern 3
	ge errorq8=(q8==1 & q9<.)



	**************************************************
	*** Step 8: Identify illegal responses
	**************************************************
	log using "C:\source\extra\pupilroster_inspect.smcl", replace
	inspect
	log close

	**************************************************
	*** Step 12: Reviewing errors and computing responses
	**************************************************
        *skip pattern 1
        replace q2=. if (q1==1 & q2>0)	
        ge errorq1_1=(q1==1 & q2<.) 


	*skip pattern 2
	replace q7=. if (q6==1 & q7>0)
	ge errorq6_1=(q6==1 & q7<.)

	*skip pattern 3
        replace q9=. if (q8==1 & q9>0)      
	ge errorq8_1=(q8==1 & q9<.)

	su err* 
        drop err*
	

	**************************************************
	*** FINAL STEP : Delivrables
	**************************************************

	*Codebook

	log using "C:\source\extra\pupilroster_codebook_final.smcl", replace
	codebook, compact
	log close

	*Save cleaned data
	save "C:\source\4- Data\4.3. Clean Data\4.3.1. Final Data\pupilroster.dta", replace