
	***************************
	* File: Teacher Questionnaire 
	* Questionnaire type: Education sector
	* Country: Zambia
	*****************************

	clear
	set mem 700m
	set more off
	cd  "C:\source\4- Data\4.1. Raw Data"


	use "Teachers.dta",clear

	**************************************************
	*** Step 1: Ensure all variables are present and labeled.
	**************************************************

	la values schoolco schoolco
	la values s1q2 s1q2
	la values s3q7e  othersourceincome

	la var s3q8  "percentage of other income"
	la values s3q8 percentage_of_other_income


	**************************************************
	*** Step 2: Ensure response value labels are correct.
	**************************************************
	label save using "Teachers.dta", replace



	**************************************************
	*** Step 4: Recode missing values
	***************************************************


	qui mvdecode s3q8, mv(10=.n)
	qui mvdecode s2q5, mv(10=.n)
        qui mvdecode s2q7, mv(10=.n)
	qui mvdecode s1q6, mv(10=.n)
	qui mvdecode s1q9, mv(10=.n)
	qui mvdecode s1q13, mv(10=.n)
	qui mvdecode s1q14, mv(10=.n)
	qui mvdecode s1q15, mv(10=.n)
	qui mvdecode s1q18, mv(10=.n)

	**************************************************
	*** Step 6: Identify skip patterns
	**************************************************
	* Recode missing values to Stata missing values, for tests and data inspection.
	quietly mvdecode _all,mv (-666 = .d \ -777 = .n \ -888 = .l \ -99 = .r) 

	*skip pattern 1
	ge errors1q6 =(s1q5 ==1 & s1q6<.)

	*skip pattern 2
	ge errors1q8=(s1q8==1 & s1q9<.) | (s1q8==3 & s1q9<.)|(s1q8==4 & s1q9<.)|(s1q8==5 & s1q9<.)

	*skip pattern 3
	ge errors1q12=((s1q12==2 & s1q13<.)| (s1q12==2 & s1q14<.)|(s1q12==2 & s1q15<.))

        *skip pattern 4
        ge errors1q14=((s1q14==2 & s1q15<.)| (s1q14==3 & s1q15<.)|(s1q14==4 & s1q15<.)|(s1q14==5 & s1q15<.))

        * skip pattern 5
        ge errors1q16=((s1q16==2 & s1q17<.)| (s1q16==2 & s1q18<.)|(s1q16==2 & s1q19a<.)|(s1q16==2 & s1q19b<.)|(s1q16==2 & s1q20<.))

        * skip pattern 6
	ge errors2q6=(s2q6 ==2 & s2q7 <.)

	*skip pattern 7
	ge errors2q9=((s2q9==2 & s2q10<.)|(s2q9==2 & s2q11<.))

	*skip pattern 8
	
        foreach v of varlist  s2q12 s2q13 { 
  	ge error`v'=( s2q9==1 & `v' <.) 
  	}

	*skip pattern 9
	
	ge errors3q3a=(s3q2a==2 & s3q3a <.) 
	ge errors3q3b=(s3q2b==2 & s3q3b <.)
	ge errors3q3c=(s3q2c==2 & s3q3c <.)
	ge errors3q3d=(s3q2d==2 & s3q3d <.)
	ge errors3q3e=(s3q2e==2 & s3q3e <.)
	ge errors3q3f=(s3q2f==2 & s3q3f <.)
	ge errors3q3g=(s3q2g==2 & s3q3g <.)

	ge errors3q4a=(s3q2a==2 & s3q4a <.)
	ge errors3q4b=(s3q2b==2 & s3q4b <.)
	ge errors3q4c=(s3q2c==2 & s3q4c <.)
	ge errors3q4d=(s3q2d==2 & s3q4d <.)
	ge errors3q4e=(s3q2e==2 & s3q4e <.)	
	ge errors3q4f=(s3q2f==2 & s3q4f <.)
	ge errors3q4g=(s3q2g==2 & s3q4g <.)

        *skip pattern 10
       
        ge errors3q7a=(s3q7a==2 & s3q8<.) 
	ge errors3q7b=(s3q7b==2 & s3q8<.) 
	ge errors3q7c=(s3q7c==2 & s3q8<.) 
	ge errors3q7d=(s3q7d==2 & s3q8<.) 
  	ge errors3q7e=(s3q7e==2 & s3q8<.) 

   

	**************************************************
	*** Step 8: Identify illegal responses
	**************************************************

	la var s3q8  "percentage of other income"
	log using "C:\source\extra\Teachers_inspect.smcl", replace
	inspect
	log  close



	**************************************************
	*** Step 10: Identify outliers
	**************************************************
	log using "c:\source\extra\Teachers_outlier.smcl", replace

	grubbs s1q10  s1q17  s3q8, level(99.99)

	log close



	**************************************************
	*** Step 12: Reviewing errors and computing responses
	*************************************************
	

	*skip pattern 1
	replace s1q6=. if (s1q5==1 & s1q6==.n)
	ge errors1q61 =(s1q5 ==1 & s1q6<. )

	*skip pattern 2
	replace s1q9=. if (s1q8==1 & s1q9==.n)|(s1q8==3 & s1q9==.n)|(s1q8==4 & s1q9==.n)|(s1q8==5 & s1q9==.n)
	ge errors1q81=(s1q8==1 & s1q9<.) |(s1q8==3 & s1q9<.)|(s1q8==4 & s1q9<.)|(s1q8==5 & s1q9<.)


        *skip pattern 3
        replace s1q13=. if (s1q12==2 & s1q13==0)
        replace s1q14=. if (s1q12==2 & s1q14==.n)
        replace s1q15=. if (s1q12==2 & s1q15==.n)
        ge errors1q121=((s1q12==2 & s1q13<.)| (s1q12==2 & s1q14<.)|(s1q12==2 & s1q15<.))

 
        *skip pattern 5 too many errors and will not correct over 60 percent of the data

	*skip pattern 6
        replace s2q7=. if (s2q6==2 & s2q7==.n)|(s2q6==2 & s2q7==1997)|(s2q6==2 & s2q7==1999)|(s2q6==2 & s2q7==2002)
        ge errors2q61=(s2q6 ==2 & s2q7 <.)

	
	*skip pattern 9
	replace s3q3a=. if s3q2a==2 & s3q3a==0
	replace s3q3b=. if s3q2b==2 & s3q3b==0 
	replace s3q3c=. if s3q2c==2 & s3q3c==0
	replace s3q3d=. if s3q2d==2 & s3q3d==0
	replace s3q3e=. if s3q2e==2 & s3q3e==0
	replace s3q3f=. if s3q2f==2 & s3q3f==0
	replace s3q3g=. if s3q2g==2 & s3q3g==0

	replace s3q4a=. if s3q2a==2 & s3q4a==0
	replace s3q4b=. if s3q2b==2 & s3q4b==0
	replace s3q4c=. if s3q2c==2 & s3q4c==0
	replace s3q4d=. if s3q2d==2 & s3q4d==0
	replace s3q4e=. if s3q2e==2 & s3q4e==0
	replace s3q4f=. if s3q2f==2 & s3q4f==0
	replace s3q4g=. if s3q2g==2 & s3q4g==0

	ge errors3q3a1=(s3q2a==2 & s3q3a <.) 
	ge errors3q3b1=(s3q2b==2 & s3q3b <.)
	ge errors3q3c1=(s3q2c==2 & s3q3c <.)
	ge errors3q3d1=(s3q2d==2 & s3q3d <.)
	ge errors3q3e1=(s3q2e==2 & s3q3e <.)
	ge errors3q3f1=(s3q2f==2 & s3q3f <.)
	ge errors3q3g1=(s3q2g==2 & s3q3g <.)

	ge errors3q4a1=(s3q2a==2 & s3q4a <.)
	ge errors3q4b1=(s3q2b==2 & s3q4b <.)
	ge errors3q4c1=(s3q2c==2 & s3q4c <.)
	ge errors3q4d1=(s3q2d==2 & s3q4d <.)
	ge errors3q4e1=(s3q2e==2 & s3q4e <.)
	ge errors3q4f1=(s3q2f==2 & s3q4f <.)
	ge errors3q4g1=(s3q2g==2 & s3q4g <.)


	*skip pattern 10
        *s3q7a-e and s3q8 questions, there are many peopel answered s3q8 questions though they confirmed no in s3q7.
	*this skip pattern is not correct due to too many errors.
	

	su  err*

	drop err* grubbs*  schoolna


	**************************************************
	*** FINAL STEP : Delivrables
	**************************************************

	log using "C:\source\4- Data\4.3. Clean Data\4.3.3. Data Code Book\Teachers_codebook.smcl", replace
	codebook, compact
	log close



	*Save cleaned data

	save "C:\source\4- Data\4.3. Clean Data\4.3.1. Final Data\Teachers_final.dta", replace

